#ifndef DEFAULTS_H_
#define DEFAULTS_H_

/* Default values for file and directory locations used by the server,
   and for some features.  You may edit this before running 'make'
   to change those defaults and enable/disable some features.  */

/**********************************************************************/
/* You may want to change these, since you can't override them from   */
/* the commandline.                                                   */

/* We log to the LOG_DAEMON syslog facility.
   See syslog(3) for other possible facility names */
#define LOG_FACILITY LOG_DAEMON

/* Absolute path to private snmp community strings file.
   Only used by the optional 'dhcpcmd' command
   Don't bother fiddling with this if you aren't going to use the 'dhcpcmd' command */
#define PRIV_FILE "/etc/snmpd.private"
/*                                                                    */
/**********************************************************************/



/**********************************************************************/
/* Unless you are doing server development, leave these alone.        */

/* Define DEBUG only if you want the debugging code added.  That's not 
   the same as the normall debugging output you get with the -d option;
   the code added by DEBUG is low-level stuff, to help track down bugs
   in the server itself.   You should normally leave it out, since the 
   code added by DEBUG isn't cheap. */
/* #define DEBUG */
/*                                                                    */
/**********************************************************************/



/**********************************************************************/
/* You probably shouldn't need to change any of these, since you may  */
/* override each of them from the commandline.                        */

/* Absolute path to pidfile. */ 
#define PID_FILE "/etc/dhcpd.pid"

/* Absolute path to bootptab file. */
#define TAB_FILE "/etc/bootptab"

/* Absolute path to dhcpd.conf file. */ 
#define CONFIG_FILE "/etc/dhcpd.conf"

/* Absolute path to bindings directory. */ 
#define LASTBINDDIR "/etc/bindings"

/* Absolute path to bootptab dump file. */ 
#define DUMPTAB_FILE "/tmp/bootpd.dump"

/* Absolute path to bindings dump file. */ 
#define DUMPBIND_FILE "/tmp/bind.dump"

/* Absolute path to working directory. */ 
#define CHDIR_PATH "/"

/* Whether or not the "Check File Access" feature is enabled.
  If the "Check File Access" feature is enabled, then when we receive
  a BOOTPREQUEST with a non-null 'file' field, we check to verify the
  file exists and is accessible on the server.  (If 'file' is a relative
  pathname, it is taken relative to our current working directory.)  If
  the file does not exist, or is not accessible, we will not respond to
  the client.)  If you store bootfiles on servers other than the one
  running dhcpd, then you should disable the Check Files Access feature.
  If CHECK_FILE_ACCESS is defined, the "Check File Access" feature is enabled.
  Comment the next line out to disable the feature. */
#define CHECK_FILE_ACCESS

/* By default, main.c will attempt to add a host route to 255.255.255.255.
   This route seems to be necessary on some systems to allow us to send
   broadcast packets to that IP address.  The code that adds that route
   has some portability problems.  If it won't compile on your system,
   exclude that code by uncommenting the definition below.    Once you
   do this, if your platform needs that route to work right, you'll need
   to add the route manually before starting the daemon. */
/* #define NOBROADCAST */

/*                                                                    */
/**********************************************************************/



/**********************************************************************/
/* Other stuff you shouldn't need to change                           */

/* Number of hash buckets for bindings directory.
   Don't change this! */
#define HASHTABLESIZE 257

/* An old (undocumented?) feature to record requests from unknown hw addrs */
#define UNKNOWN
/*                                                                    */
/**********************************************************************/

#endif /* DEFAULTS_H_ */
